<?php

namespace Teknisa\SM\Factory;

use Doctrine\ORM\EntityManager;

class Sm00015004AgendamentoDeRecursoFactory {
    
    protected $connection;
    
    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
    }
    
    /**
     * Retorna os item da proposta
     */
    public function getItensProposta(array $params){
        $sql = "SELECT NRITEMORCAMENTO,
                       QTITEMORCAMENTO
                FROM FCT_ITEMORCAMENTO
                WHERE NRSEQORCAMENTO = :NRSEQORCAMENTO
                    AND NRORG        = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function getItensContrato(array $params) {
        $sql = "SELECT NRITEMOCONTRATO,
                       QTITEMCONTRATO
                  FROM FCT_ITEMCONTRATO
                 WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                   AND NRORG         = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function inserirAgendamentoPendente(array $params) {
        $sql = "INSERT INTO FCT_AGENDPENDENTE (
                    NRAGENDPENDENTE   , NRAGENDRECURSOCONT  , NRSEQCONTRATO  ,
                    NRITEMOCONTRATO   , QTPENDENCIA         , IDPENDENCIA    ,
                    DTINIAGENDAMENTO  , DTFINAGENDAMENTO    , NRORG          ,
                    IDATIVO           , DTINCLUSAO          , NRORGINCLUSAO  ,
                    CDOPERINCLUSAO    , NRSEQORCAMENTO      , NRITEMORCAMENTO
                )
                VALUES (
                    :NRAGENDPENDENTE  , :NRAGENDRECURSOCONT , :NRSEQCONTRATO ,
                    :NRITEMOCONTRATO  , :QTPENDENCIA        , :IDPENDENCIA   ,
                    :DTINIAGENDAMENTO , :DTFINAGENDAMENTO   , :NRORG         ,
                    :IDATIVO          , SYSDATE             , :NRORGINCLUSAO ,
                    :CDOPERINCLUSAO   , :NRSEQORCAMENTO     , :NRITEMORCAMENTO
                )";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    public function getAgendamentosPendentes(array $params) {
        $sql = "SELECT DISTINCT TO_CHAR(DTAGENDAMENTO, 'DD/MM/YYYY') AS DTAGENDAMENTO
                  FROM FCT_AGENDPENDENTE
                 WHERE NRAGENDRECURSOCONT = :NRAGENDRECURSOCONT
                   AND NRORG              = :NRORG
                 ORDER BY DTAGENDAMENTO";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function excluirAgendamentoPendente(array $params) {
        $sql = "DELETE FROM FCT_AGENDPENDENTE
                 WHERE NRAGENDRECURSOCONT   = :NRAGENDRECURSOCONT
                   AND TRUNC(DTAGENDAMENTO) = :DTAGENDAMENTO
                   AND NRORG                = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    /**
     * Retorna o período do contrato (data de início e fim)
     */
    public function getPeriodoContrato(array $params) {
        $sql = "SELECT TO_CHAR(DTINICIOCONTRATO, 'DD/MM/YYYY') AS DTINICIOCONTRATO,
                       TO_CHAR(DTFIMCONTRATO, 'DD/MM/YYYY')    AS DTFIMCONTRATO
                  FROM FCT_CONTRATO
                 WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                   AND NRORG         = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    /**
     * Retorna o período da proposta (data de início e fim)
     */
    public function getPeriodoProposta(array $params) {
        $sql = "SELECT TO_CHAR(DTREFORCAMENTO, 'DD/MM/YYYY') AS DTINIPROPOSTA,
                       TO_CHAR(DTVALIDADE, 'DD/MM/YYYY') AS DTFIMPROPOSTA
                FROM FCT_ORCAMENTO 
                WHERE NRSEQORCAMENTO = :NRSEQORCAMENTO
                    AND NRORG        = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function atualizarRecursoAgendado(array $params) {
        $sql = "UPDATE FCT_RECURSOSAGENDCONT
                   SET IDALTERACAOEQUIPE    = :IDALTERACAOEQUIPE,
                       DSJUSTIFICAALTEQUIPE = :DSJUSTIFICAALTEQUIPE,
                       DTULTATU             = SYSDATE,
                       CDOPERULTATU         = :CDOPERULTATU,
                       NRORGULTATU          = :NRORGULTATU
                 WHERE NRAGENDRECURSOCONT  = :NRAGENDRECURSOCONT
                   AND NRRECURSOSAGENDCONT = :NRRECURSOSAGENDCONT
                   AND NRORG               = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    public function getRecursoAgendado(array $params) {
        $sql = "SELECT REC.NRRECURSOSAGENDCONT,
                       AGEN.NRSEQCONTRATO,
                       REC.NRAGENDRECURSOCONT,
                       REC.NRITEMOCONTRATO,
                       TO_CHAR(REC.DTINIAGENDRECURSO, 'DD/MM/YYYY') AS DTINIAGENDRECURSO,
                       TO_CHAR(REC.DTFIMAGENDRECURSO, 'DD/MM/YYYY') AS DTFIMAGENDRECURSO,
                       REC.IDTPRECURSO,
                       DECODE(REC.IDTPRECURSO, '1', REC.NRPARCNEPESSOA, DECODE(REC.IDTPRECURSO, '2', REC.CDBEMATIVO, REC.CDPRODUTO)) AS CHAVE,
                       REC.CDPRODUTO,
                       REC.NRPARCNEPESSOA,
                       REC.CDEMPRESA,
                       REC.CDBEMATIVO,
                       REC.CDFILIALPED,
                       REC.NRPEDIDO,
                       REC.NRITEMPED,
                       REC.NRRECURSOSUPERIOR,
                       REC.IDMOTIVOAGENDAMENTO,
                       REC.IDSITUARECGEND,
                       REC.DSATIVIDADESAGEND,
                       REC.HRPRIMEIRAENTRADA,
                       REC.HRPRIMEIRASAIDA,
                       REC.HRSEGUNDAENTRADA,
                       REC.HRSEGUNDASAIDA,
                       REC.NRTEMPOTOLERANCIA,
                       REC.IDREPETDOMINGO,
                       REC.IDREPETSEGUNDA,
                       REC.IDREPETTERCA,
                       REC.IDREPETQUARTA,
                       REC.IDREPETQUINTA,
                       REC.IDREPETSEXTA,
                       REC.IDREPETSABADO,
                       REC.IDHORAEXTRA,
                       REC.IDDESCANSOREMU,
                       REC.IDALTERACAOEQUIPE,
                       REC.NRRECURSOALTEQUIPE,
                       REC.DSJUSTIFICAALTEQUIPE
                  FROM FCT_RECURSOSAGENDCONT REC
                 INNER JOIN FCT_AGENDRECURSOCONT AGEN
                    ON REC.NRAGENDRECURSOCONT = AGEN.NRAGENDRECURSOCONT
                   AND REC.NRORG              = AGEN.NRORG
                 WHERE REC.NRAGENDRECURSOCONT  = :NRAGENDRECURSOCONT
                   AND REC.NRRECURSOSAGENDCONT = :NRRECURSOSAGENDCONT
                   AND REC.NRORG               = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function atualizarDataFinalAgendamentoRecurso(array $params) {
        $sql = "UPDATE FCT_RECURSOSAGENDCONT
                   SET DTFIMAGENDRECURSO = :DTFIMAGENDRECURSO,
                       DTULTATU          = SYSDATE,
                       CDOPERULTATU      = :CDOPERULTATU
                 WHERE NRAGENDRECURSOCONT  = :NRAGENDRECURSOCONT
                   AND NRRECURSOSAGENDCONT = :NRRECURSOSAGENDCONT
                   AND NRORG               = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    public function verificarSeExisteCobertura(array $params) {
        $sql = "SELECT COUNT(*) AS EXISTE
                  FROM FCT_RECURSOSAGENDCONT
                 WHERE NRAGENDRECURSOCONT = :NRAGENDRECURSOCONT
                   AND NRRECURSOALTEQUIPE = :NRRECURSOALTEQUIPE
                   AND (TRUNC(DTINIAGENDRECURSO) BETWEEN :DATAINICIAL AND :DATAFINAL
                    OR TRUNC(DTFIMAGENDRECURSO)  BETWEEN :DATAINICIAL AND :DATAFINAL)
                   AND NRORG = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    /**
     * Atualiza a tabela de agendamentos pendentes após o aceite de uma proposta
    **/
    public function atualizarAgendamentoPendente(array $params){
        if($params["IDPENDENCIA"] == "5"){
            $sql = "UPDATE FCT_AGENDPENDENTE
                    SET IDPENDENCIA     = :IDPENDENCIA,
                        NRSEQCONTRATO   = :NRSEQCONTRATO,
                        NRITEMOCONTRATO = :NRITEMOCONTRATO
                    WHERE NRSEQORCAMENTO    = :NRSEQORCAMENTO
                        AND NRITEMORCAMENTO = :NRITEMORCAMENTO
                        AND NRORG           = :NRORG";
        } else {
            $params = array(
                "NRSEQCONTRATO" => $params["NRSEQCONTRATO"],
                "NRORG"         => $params["NRORG"],
                "IDPENDENCIA"   => $params["IDPENDENCIA"]
            );

            $sql = "UPDATE FCT_AGENDPENDENTE
                    SET IDPENDENCIA     = :IDPENDENCIA
                    WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                        AND NRORG       = :NRORG";
        }
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
}

?>