<?php

namespace Teknisa\SM\Service;

use Teknisa\SM\Factory\SmParceiroNegocioFactory;
use Teknisa\Libs\Util\NewCode;
use Teknisa\SM\Service\SmDocumentosService;
use Teknisa\SM\Util\Utilities;
use Doctrine\ORM\EntityManager;
use Teknisa\SM\Util\Procedure\FctAtualizaCnpjCont;
use Zeedhi\Framework\Remote\FileUploader\Server;
use Zeedhi\Framework\DTO\Row;

class SmParceiroNegocioService {
    protected $parceiroFactory;
    protected $newCode;
    protected $smdocumentos;
    protected $connection;
    protected $zhFileUploader;
    protected $fileServerBaseUrl;
    
    public function __construct(SmParceiroNegocioFactory $parceiroFactory, NewCode $newCode, SmDocumentosService $smdocumentos, EntityManager $entityManager, Server $zhFileUploader, $fileServerBaseUrl) {
        $this->parceiroFactory   = $parceiroFactory;
        $this->newCode           = $newCode;
        $this->smdocumentos      = $smdocumentos;
        $this->connection        = $entityManager->getConnection();
        $this->zhFileUploader    = $zhFileUploader;
        $this->fileServerBaseUrl = $fileServerBaseUrl;
    }
    
    public function getPermissaoAlteracaoInscParceiro($nrparcnegocio, $nrorg) {
        try{
            $params = array(
                "NRPARCNEGOCIO" => $nrparcnegocio,
                "NRORG"         => $nrorg
            );
            
            $contratosDelphi = $this->parceiroFactory->getContratosApenasDelphi($params);
            return count($contratosDelphi) > 0 ? false : true;
        } catch(\Exception $e) {
            if(strrpos($e->getMessage(), "ORA-00942"))
                return true;
            else 
                throw $e;
        }
    }
    
    public function alterarInscricaoParceiro($nrparcnegocio, $nrnewinscricao, $nroldinscricao, $nmprincipalparc, $nmsecundarioparc, $dsjustificativa, $idinativaparc, $dscaminhoarq, $nrorg, $operador) {
        $this->connection->beginTransaction();
        try {
            $this->executarProcedureAltCnpj($nrnewinscricao, $nroldinscricao, $nmprincipalparc, $nmsecundarioparc, $dsjustificativa, $idinativaparc, $nrorg, $operador);
            $this->inserirLogAltCnpjParceiro($nrparcnegocio, $nrnewinscricao, $nroldinscricao, $dscaminhoarq, $dsjustificativa, $nrorg, $operador);
            $this->connection->commit();
        } catch(\Exception $e) {
            $this->connection->rollback();
            throw $e;
            
        }
        
    }
    public function validarAlteracaoInscricao( $nrnewinscricao, $nrorg){
        
        try {
            $params = array("NRINSJUREMPR" => $nrnewinscricao);
            
            $valida = $this->parceiroFactory->validaOrganizacao($params);
            
            if($valida>0){
                
                $retorno = "TEM_ORG";
            } else {
                
                $params = array("NRINSCRICAOPARC" => $nrnewinscricao, 
                                "NRORG" => $nrorg);
                                
                $valida = $this->parceiroFactory->validaParceiro($params);
                    
                    if($valida>0){
                        
                        $retorno = "TEM_PARC";
                    } else {
                        
                        $retorno = "OK";
                    }
            }
            return $retorno;
        } catch(\Exception $e) {
            
        }
    }
    
    public function executarProcedureAltCnpj($nrnewinscricao, $nroldinscricao, $nmprincipalparc, $nmsecundarioparc, $dsjustificativa, $idinativaparc, $nrorg, $operador){
        $procedure = new FctAtualizaCnpjCont($this->connection);
        $procedure->executar($nrnewinscricao, $nroldinscricao, $nmprincipalparc, $nmsecundarioparc, $dsjustificativa, $idinativaparc, $nrorg, $operador);
    }
    
    public function inserirLogAltCnpjParceiro($nrparceiro, $nrnewinscricao, $nroldinscricao, $dscaminhoarq, $dsjustificativa, $nrorg, $operador) {
        $nraltcnpjparceiro = $this->newCode->getCodeByTableName("FCT_LOGALTCNPJPARCEIRO", $nrorg, 1, 10, true);
        
        $file = null;
        if (is_array($dscaminhoarq) && count($dscaminhoarq) > 0) {
            $file = $this->anexarDocumentoFileServer($dscaminhoarq[0]);
        }
        
        $params = array(
            "NRALTCNPJPARCEIRO" => $nraltcnpjparceiro,
            "NROLDINSCRICAO"    => $nroldinscricao,
            "NRNEWINSCRICAO"    => $nrnewinscricao,
            "DSJUSTIFICATIVA"   => $dsjustificativa,
            "NMARQUIVO"         => $file ? $file["name"] : null,
            "DSTIPO"            => $file ? $file["type"] : null,
            "VRTAMANHO"         => $file ? $file["size"] : null,
            "DSCAMINHOARQ"      => $file ? $file["path"] : null,
            "NRORG"             => $nrorg,
            "CDOPERINCLUSAO"    => $operador
        );
        $this->parceiroFactory->inserirLogAltCnpjParceiro($params);
        
        if ($file) {
            $this->anexarDocumentoContrato($nrnewinscricao, $file, $nrorg, $operador);
        }
    }
    
    public function anexarDocumentoFileServer($fileData){
        $row = new Row(array('FILE' => array($fileData)));
        $this->zhFileUploader->uploadFilesInRow($row, 'FILE', 'anexo_termo_anuencia_contrato');
        
        return $row["FILE"][0];
    }
    
    public function anexarDocumentoContrato($nrnewinscricao, $arquivo, $nrorg, $operador) {
        $contratos = $this->getContratosParceiro($nrnewinscricao, $nrorg);
        foreach($contratos as $contrato) {
            $nomeArquivo   = $arquivo["name"];
            $tipo          = $arquivo["type"];
            $tamanhoBytes  = $arquivo["size"] * 1024;
            $urlFileServer = $arquivo["path"];
            
            if (!empty($urlFileServer)) {
                $conteudo = $this->smdocumentos->getDocumentoFileServer($this->fileServerBaseUrl . $urlFileServer, $nrorg);
                if ($conteudo !== false) {
                    $file = Utilities::uploadFileServer($this->zhFileUploader, "anexo_termo_anuencia_contrato", $nomeArquivo, $conteudo, $tamanhoBytes, $tipo);
                    $nranexocontrato = $this->newCode->getCodeByTableName("FCT_ANEXOCONTRATO", $nrorg, 1, 10, true);
                    $params = array(
                        "NRANEXOCONTRATO" => $nranexocontrato,
                        "NRSEQCONTRATO"   => $contrato["NRSEQCONTRATO"],
                        "DSCAMINHO"       => $file["path"],
                        "NMARQUIVO"       => $nomeArquivo,
                        "DSTIPO"          => $tipo,
                        "VRTAMANHO"       => $tamanhoBytes,
                        "NRORG"           => $nrorg,
                        "CDOPERINCLUSAO"  => $operador
                    );
                    $this->parceiroFactory->inserirAnexoContrato($params);
                }
            }
        }
    }
    
    public function getContratosParceiro($nrnewinscricao, $nrorg) {
        $params = array(
            "NRINSCRICAOPARC" => $nrnewinscricao,
            "NRORG"           => $nrorg
        );
        
        return $this->parceiroFactory->getContratosParceiro($params); 
    }
    
    public function getTermoAnuenciaParceiro($nrinscricao, $nrorg) {
        try { 
            $result = array();
            $params = array(
                "NRINSCRICAOPARC" => $nrinscricao,
                "NRORG"           => $nrorg
            );
            
            $documentos = $this->parceiroFactory->getTermoAnuenciaParceiro($params); 
            if(count($documentos) <= 0) {
                throw new \Exception("Operação bloqueada!<br>Não há termos de anuência ligados a este parceiro de negócio.");
            } else {
                foreach($documentos as $documento) {
                    $microtime = microtime(true);
                    $microtime = str_replace(".", "_", $microtime);
                    
                    $fileDir   = $this->fileServerBaseUrl . $documento["DSCAMINHOARQ"];
                    $fileName  = $microtime . "_" . str_replace(",", "_", $documento["NMARQUIVO"]);
                    
                    $fileDirTemp = $this->smdocumentos->downloadDocFileServer($fileDir, $fileName, $nrorg);
                    $fileName    = base64_encode($fileName);
                    $result[]    = "/downloadArquivo?requestType=Row&row[FILENAME]=" . $fileName . "&row[FILETYPE]=" . $documento["DSTIPO"];
                }
            }
            
            return $result;
        } catch(\Exception $e) {
            throw $e;
        }
    }
}
?>
